Skip to contents

Report Manager Module

Usage

tm_report_manager(reports_path = "reports", auto_save = TRUE)

Arguments

reports_path

character. Absolute path where reports should be stored.

auto_save

logical. Whether to save active report whenever there are any changes made.

Details

This module supports collaborative work on teal reports, generated by teal.reporter package. This module extends functionalities of teal.reporter and allows to store reports in chosen path. Reports will be stored as JSON files inside folders named after reports.

Examples


app <- teal::init(
  data = teal.data::teal_data(IRIS = iris),
  modules = teal::modules(
    teal::example_module(transformators = list(or_filtering_transformator("IRIS"))),
    tm_report_manager()
  )
)
#> module "Report Manager" server function takes no data so "datanames" will be ignored
if (interactive()) {
  shinyApp(app$ui, app$server)
}